make the value of an option optional (found by lubek)
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index 93f8bce..8e73bfe 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -2,9 +2,9 @@
  * libuci - Library for the Unified Configuration Interface
  * Copyright (C) 2008 Felix Fietkau <nbd@openwrt.org>
  *
- * this program is free software; you can redistribute it and/or modify
- * it under the terms of the gnu lesser general public license version 2.1
- * as published by the free software foundation
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -105,6 +105,7 @@ extern void uci_perror(struct uci_context *ctx, const char *str);
  * @single: ignore the 'package' keyword and parse everything into a single package
  *
  * the name parameter is for config files that don't explicitly use the 'package <...>' keyword
+ * if 'package' points to a non-null struct pointer, enable history tracking and merge 
  */
 extern int uci_import(struct uci_context *ctx, FILE *stream, const char *name, struct uci_package **package, bool single);
 
@@ -213,30 +214,65 @@ extern int uci_save(struct uci_context *ctx, struct uci_package *p);
  * uci_commit: commit changes to a package
  * @ctx: uci context
  * @p: uci_package struct pointer
+ * @overwrite: overwrite existing config data and flush history
  *
  * committing may reload the whole uci_package data,
  * the supplied pointer is updated accordingly
  */
-extern int uci_commit(struct uci_context *ctx, struct uci_package **p);
+extern int uci_commit(struct uci_context *ctx, struct uci_package **p, bool overwrite);
 
 /**
  * uci_list_configs: List available uci config files
- *
  * @ctx: uci context
  */
 extern int uci_list_configs(struct uci_context *ctx, char ***list);
 
+/** 
+ * uci_set_savedir: override the default history save directory
+ * @ctx: uci context
+ * @dir: directory name
+ */
+extern int uci_set_savedir(struct uci_context *ctx, const char *dir);
+
+/** 
+ * uci_set_savedir: override the default config storage directory
+ * @ctx: uci context
+ * @dir: directory name
+ */
+extern int uci_set_confdir(struct uci_context *ctx, const char *dir);
+
+/**
+ * uci_add_history_path: add a directory to the search path for change history files
+ * @ctx: uci context
+ * @dir: directory name
+ *
+ * This function allows you to add directories, which contain 'overlays'
+ * for the active config, that will never be committed.
+ */
+extern int uci_add_history_path(struct uci_context *ctx, const char *dir);
+
+/**
+ * uci_revert: revert all changes to a config item
+ * @ctx: uci context
+ * @p: pointer to a uci_package struct ptr (will be replaced by the revert)
+ * @section: section name (optional)
+ * @option option name (optional)
+ */
+extern int uci_revert(struct uci_context *ctx, struct uci_package **p, char *section, char *option);
+
 /* UCI data structures */
 enum uci_type {
        UCI_TYPE_HISTORY = 0,
        UCI_TYPE_PACKAGE = 1,
        UCI_TYPE_SECTION = 2,
-       UCI_TYPE_OPTION = 3
+       UCI_TYPE_OPTION = 3,
+       UCI_TYPE_PATH = 4
 };
 
 enum uci_flags {
-       UCI_FLAG_STRICT = (1 << 0), /* strict mode for the parser */
-       UCI_FLAG_PERROR = (1 << 1), /* print error messages to stderr */
+       UCI_FLAG_STRICT =      (1 << 0), /* strict mode for the parser */
+       UCI_FLAG_PERROR =      (1 << 1), /* print parser error messages */
+       UCI_FLAG_EXPORT_NAME = (1 << 2), /* when exporting, name unnamed sections */
 };
 
 struct uci_element
@@ -257,6 +293,12 @@ struct uci_context
        /* uci runtime flags */
        enum uci_flags flags;
 
+       char *confdir;
+       char *savedir;
+
+       /* search path for history files */
+       struct uci_list history_path;
+
        /* private: */
        int errno;
        const char *func;
@@ -276,6 +318,7 @@ struct uci_parse_context
        /* private: */
        struct uci_package *package;
        struct uci_section *section;
+       bool merge;
        FILE *file;
        const char *name;
        char *buf;